@@ -209,7 +209,7 @@ irrad.source_spct <-
     if (use.hinges) {
       all.hinges <- NULL
       for (wb in w.band) {
-        all.hinges <- c(all.hinges, wb$hinges)
+        all.hinges <- c(all.hinges, wb[["hinges"]])
       }
       lst <- l_insert_hinges(w.length, s.irrad, all.hinges)
       w.length <- lst[["x"]]
